==> oauth1-client-2.10.1-sources.jar: org/glassfish/jersey/client/oauth1/ConsumerCredentials.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.client.oauth1;

/**
 * Consumer credentials class (credentials issued by the Service Provider for the application).
 * The class stores client secret as byte array to improve security.
 *
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 * @since 2.3
 */
public final class ConsumerCredentials {

    private final String consumerKey;
    private final byte[] consumerSecret;


    /**
     * Create new consumer credentials.
     *
     * @param consumerKey Consumer key.
     * @param consumerSecret Consumer secret.
     */
    public ConsumerCredentials(String consumerKey, String consumerSecret) {
        this.consumerKey = consumerKey;
        this.consumerSecret = consumerSecret.getBytes();
    }

    /**
     * Create a new consumer credentials with secret defined as byte array.
     *
     * @param consumerKey Consumer key.
     * @param consumerSecret Consumer secret as byte array.
     */
    public ConsumerCredentials(String consumerKey, byte[] consumerSecret) {
        this.consumerKey = consumerKey;
        this.consumerSecret = consumerSecret;
    }

    /**
     * Get consumer key.
     *
     * @return Consumer key.
     */
    public String getConsumerKey() {
        return consumerKey;
    }

    /**
     * Get consumer secret.
     *
     * @return Consumer secret.
     */
    public String getConsumerSecret() {
        return new String(consumerSecret);
    }

    /**
     * Get consumer secret as a byte array (in default encoding).
     *
     * @return Consumer secret.
     */
    public byte[] getConsumerSecretAsByteArray() {
        return consumerSecret;
    }

}

==> oauth1-client-2.15-sources.jar: org/glassfish/jersey/client/oauth1/ConsumerCredentials.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.client.oauth1;

/**
 * Consumer credentials class (credentials issued by the Service Provider for the application).
 * The class stores client secret as byte array to improve security.
 *
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 * @since 2.3
 */
public final class ConsumerCredentials {

    private final String consumerKey;
    private final byte[] consumerSecret;


    /**
     * Create new consumer credentials.
     *
     * @param consumerKey Consumer key.
     * @param consumerSecret Consumer secret.
     */
    public ConsumerCredentials(final String consumerKey, final String consumerSecret) {
        this.consumerKey = consumerKey;
        this.consumerSecret = consumerSecret.getBytes();
    }

    /**
     * Create a new consumer credentials with secret defined as byte array.
     *
     * @param consumerKey Consumer key.
     * @param consumerSecret Consumer secret as byte array in the default encoding.
     */
    public ConsumerCredentials(final String consumerKey, final byte[] consumerSecret) {
        this.consumerKey = consumerKey;
        this.consumerSecret = consumerSecret;
    }

    /**
     * Get consumer key.
     *
     * @return Consumer key.
     */
    public String getConsumerKey() {
        return consumerKey;
    }

    /**
     * Get consumer secret.
     *
     * @return Consumer secret.
     */
    public String getConsumerSecret() {
        return new String(consumerSecret);
    }

    /**
     * Get consumer secret as a byte array (in default encoding).
     *
     * @return Consumer secret.
     */
    public byte[] getConsumerSecretAsByteArray() {
        return consumerSecret;
    }

}
